@@ -29,7 +29,7 @@ class AnalysisSTEAM:
         Class to run analysis based on STEAM_SDK
     """
 
-    def __init__(self, file_name_analysis: str,
+    def __init__(self, file_name_analysis: str = None,
                  relative_path_settings: str = '',
                  verbose: bool = False):
         """
@@ -40,7 +40,6 @@ class AnalysisSTEAM:
         """
 
         # Initialize
-        self.data_analysis = yaml_to_data(file_name_analysis, DataAnalysis)  # Load yaml keys into DataAnalysis dataclass
         self.settings = DataSettings()  # object containing the settings acquired during initialization
         self.library_path = None
         self.output_path = None
@@ -52,11 +51,16 @@ class AnalysisSTEAM:
         self.verbose = verbose
         self.overall_parameter = None  # float representing the overall outcome of a simulation for parsims
 
-        # Read working folders and set them up
-        self._set_up_working_folders()
+        if file_name_analysis:
+            self.data_analysis = yaml_to_data(file_name_analysis, DataAnalysis)  # Load yaml keys into DataAnalysis dataclass
+            # Read working folders and set them up
+            self._set_up_working_folders()
+            # Read analysis settings
+            self._load_and_write_settings(relative_path_settings)
+        else:
+            self.data_analysis = DataAnalysis()
+            if verbose: print('Empty AnalysisSTEAM() object generated.')
 
-        # Read analysis settings
-        self._load_and_write_settings(relative_path_settings)
 
     def setAttribute(self, dataclassSTEAM, attribute: str, value):
         try:
@@ -933,7 +937,7 @@ class AnalysisSTEAM:
         list_stl_files = [entry for entry in os.listdir(stl_path) if
                           (simulation_name in entry) and ('.csv' in entry)]
         for stl_file in list_stl_files:
-            file_to_copy = os.path.join(self.output_path, stl_file)
+            file_to_copy = os.path.join(stl_path, stl_file) #self.output_path was first argument; changed it to stl_path
             file_copied = os.path.join(stl_path_new, stl_file)
             shutil.copyfile(file_to_copy, file_copied)
             if self.verbose: print('Stl file {} copied to {}.'.format(file_to_copy, file_copied))
