@@ -133,24 +133,24 @@ def calculate_short_parameters(start_index, pair, short_position_name,
     sim3D_idxFinerMeshHalfTurn = [int(idx_contact_from[original_pair_idx]), int(idx_contact_to[original_pair_idx])]
 
     # Identify the half-turns that are physically adjacent to the above-mentioned half-turns, to which finer mesh will be applied as well - contact along width
-    if len(np.where(iContactAlongWidth_From == idx_contact_from[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_To[int(np.where(iContactAlongWidth_From == idx_contact_from[original_pair_idx])[0])])  # add half-turns touching the 1st half-turn along its width
-    if len(np.where(iContactAlongWidth_To == idx_contact_from[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_From[int(np.where(iContactAlongWidth_To == idx_contact_from[original_pair_idx])[0])])  # add half-turns touching the 1st half-turn along its width (repeated in case the index is in "to" and not "from")
-    if len(np.where(iContactAlongWidth_From == idx_contact_to[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_To[int(np.where(iContactAlongWidth_From == idx_contact_to[original_pair_idx])[0])])  # add half-turns touching the 2nd half-turn along its width
-    if len(np.where(iContactAlongWidth_To == idx_contact_to[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_From[int(np.where(iContactAlongWidth_To == idx_contact_to[original_pair_idx])[0])])  # add half-turns touching the 2nd half-turn along its width (repeated in case the index is in "to" and not "from")
+    for i in np.where(iContactAlongWidth_From == idx_contact_from[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_To[i])  # add half-turns touching the 1st half-turn along its width
+    for i in np.where(iContactAlongWidth_To == idx_contact_from[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_From[i])  # add half-turns touching the 1st half-turn along its width (repeated in case the index is in "to" and not "from")
+    for i in np.where(iContactAlongWidth_From == idx_contact_to[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_To[i])  # add half-turns touching the 2nd half-turn along its width
+    for i in np.where(iContactAlongWidth_To == idx_contact_to[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongWidth_From[i])  # add half-turns touching the 2nd half-turn along its width (repeated in case the index is in "to" and not "from")
 
     # Identify the half-turns that are physically adjacent to the above-mentioned half-turns, to which finer mesh will be applied as well - contact along height
-    if len(np.where(iContactAlongHeight_From == idx_contact_from[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_To[int(np.where(iContactAlongHeight_From == idx_contact_from[original_pair_idx])[0])])  # add half-turns touching the 1st half-turn along its height
-    if len(np.where(iContactAlongHeight_To == idx_contact_from[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_From[int(np.where(iContactAlongHeight_To == idx_contact_from[original_pair_idx])[0])])  # add half-turns touching the 1st half-turn along its height (repeated in case the index is in "to" and not "from")
-    if len(np.where(iContactAlongHeight_From == idx_contact_to[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_To[int(np.where(iContactAlongHeight_From == idx_contact_to[original_pair_idx])[0])])  # add half-turns touching the 2nd half-turn along its height
-    if len(np.where(iContactAlongHeight_To == idx_contact_to[original_pair_idx])[0]) > 0:
-        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_From[int(np.where(iContactAlongHeight_To == idx_contact_to[original_pair_idx])[0])])  # add half-turns touching the 2nd half-turn along its height (repeated in case the index is in "to" and not "from")
+    for i in np.where(iContactAlongHeight_From == idx_contact_from[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_To[i])  # add half-turns touching the 1st half-turn along its height
+    for i in np.where(iContactAlongHeight_To == idx_contact_from[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_From[i])  # add half-turns touching the 1st half-turn along its height (repeated in case the index is in "to" and not "from")
+    for i in np.where(iContactAlongHeight_From == idx_contact_to[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_To[i])  # add half-turns touching the 2nd half-turn along its height
+    for i in np.where(iContactAlongHeight_To == idx_contact_to[original_pair_idx])[0]:
+        sim3D_idxFinerMeshHalfTurn.append(iContactAlongHeight_From[i])  # add half-turns touching the 2nd half-turn along its height (repeated in case the index is in "to" and not "from")
 
     # Remove duplicates
     sim3D_idxFinerMeshHalfTurn = unique(sim3D_idxFinerMeshHalfTurn)
