@@ -184,7 +184,7 @@ class CCTDM(BaseModel):
     """
         Class for FiQuS CCT
     """
-    type: Literal['CCT']
+    type: Literal['CCT_straight']
     geometry: CCTGeometry = CCTGeometry()
     mesh: MeshCCT = MeshCCT()
     solve: SolveCCT = SolveCCT()
