@@ -13,7 +13,7 @@ import numpy as np
 import yaml
 
 from steam_sdk.data.DataModelCircuit import DataModelCircuit, Component
-from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
+from steam_sdk.parsers.ParserYAML import dict_to_yaml
 
 
 class ParserPSPICE:
