@@ -855,7 +855,7 @@ def translate_library_PSPICE_2_XYCE(in_file_library: str, out_file_library: str,
             raise Exception("Couldn't find a .ends. Please check.")
         for i in range(len(idx_start)):
             test = lines[idx_start[i]:idx_end[i]+1]
-            old_model = ''.join(lines[idx_start[i]:idx_end[i]+1])
+            old_model = ''.join(lines[idx_start[i]:idx_end[i]+1]).replace('\t',' ')
             new_model, flag_Added = translate_model_PSPICE_2_XYCE(old_model, output_path)
             new_model = new_model.split('\n')
             new_model = [x+'\n' for x in new_model]
@@ -887,9 +887,14 @@ def translate_model_PSPICE_2_XYCE(model: str, output_path: str = ''):
 
     for i in range(len(model_split)):
         line = model_split[i].replace('\t',' ')
-        if not line:
+        if not line or line==' ':
             flag_inModel = False
             continue
+        if line[0]==' ':
+            p = 0
+            while line[p]==' ':
+                p=p+1
+            line = line[p:]
         if flag_inModel and line[0]!='+':
             flag_inModel = False
         if line[0].casefold() in list_possible_sources and 'STIMULUS' in line:
